@@ -3,14 +3,14 @@
 #'
 #' @description
 #'
-#' Creates an expression from a dataframe containing statistical details.
-#' Ideally, this dataframe would come from having run `tidy_model_parameters`
+#' Creates an expression from a data frame containing statistical details.
+#' Ideally, this data frame would come from having run `tidy_model_parameters`
 #' function on your model object.
 #'
 #' This function is currently **not** stable and should not be used outside of
 #' this package context.
 #'
-#' @param data A dataframe containing details from the statistical analysis
+#' @param data A data frame containing details from the statistical analysis
 #'   and should contain some or all of the the following columns:
 #' - *statistic*: the numeric value of a statistic.
 #' - *df.error*: the numeric value of a parameter being modeled (often degrees
@@ -50,7 +50,7 @@
 #' @examples
 #' set.seed(123)
 #'
-#' # creating a dataframe with stats results
+#' # creating a data frame with stats results
 #' stats_df <- cbind.data.frame(
 #'   statistic  = 5.494,
 #'   df         = 29.234,
@@ -89,31 +89,26 @@ add_expression_col <- function(data,
                                k.df = 0L,
                                k.df.error = k.df,
                                ...) {
-  # make sure these columns are present
   if (!"n.obs" %in% colnames(data)) data %<>% mutate(n.obs = n)
   if (!"effectsize" %in% colnames(data)) data %<>% mutate(effectsize = method)
-
-  # is this a Bayesian test?
   data %<>% rename_all(.funs = recode, "bayes.factor" = "bf10")
+
   bayesian <- any("bf10" == colnames(data))
+  no.parameters <- sum("df.error" %in% names(data) + "df" %in% names(data))
 
   # special case for Bayesian contingency table analysis
-  if (bayesian && grepl("contingency", data$method[[1]])) data %<>% mutate(effectsize = "Cramers_v")
+  if (bayesian && grepl("contingency", data$method[[1]], fixed = TRUE)) data %<>% mutate(effectsize = "Cramers_v")
 
   # convert needed columns to character type
   df_expr <- .data_to_char(data, k, k.df, k.df.error)
 
-  # adding a few other columns
   df_expr %<>% mutate(
-    statistic.text     = statistic.text %||% stat_text_switch(method),
-    es.text            = effsize.text %||% estimate_type_switch(effectsize),
-    prior.distribution = prior_switch(method),
+    statistic.text     = statistic.text %||% stat_text_switch(tolower(method)),
+    es.text            = effsize.text %||% estimate_type_switch(tolower(effectsize)),
+    prior.distribution = prior_switch(tolower(method)),
     n.obs              = .prettyNum(n.obs)
   )
 
-  # how many parameters?
-  no.parameters <- sum("df.error" %in% names(data) + "df" %in% names(data))
-
   # Bayesian analysis ------------------------------
 
   if (bayesian) {
@@ -157,7 +152,6 @@ add_expression_col <- function(data,
   # convert `expression` to `language`
   df_expr %<>% .glue_to_expression()
 
-  # return data frame with some polish and formatted expression
   as_tibble(data) %>%
     relocate(matches("^effectsize$"), .before = matches("^estimate$")) %>%
     mutate(expression = df_expr$expression)
