@@ -47,8 +47,7 @@
 #' @inheritParams stats::chisq.test
 #' @inheritParams oneway_anova
 #'
-#' @examples
-#' \donttest{
+#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true")
 #' # for reproducibility
 #' set.seed(123)
 #' library(statsExpressions)
@@ -91,7 +90,6 @@
 #'   ratio  = c(0.2, 0.2, 0.3, 0.3),
 #'   type   = "bayes"
 #' )
-#' }
 #' @export
 contingency_table <- function(data,
                               x,
@@ -106,13 +104,11 @@ contingency_table <- function(data,
                               fixed.margin = "rows",
                               prior.concentration = 1,
                               ...) {
-  # standardize the type of statistics
   type <- stats_type_switch(type)
 
   # one-way or two-way table analysis?
   test <- ifelse(quo_is_null(enquo(y)), "1way", "2way")
 
-  # creating a data frame
   data %<>%
     select({{ x }}, {{ y }}, .counts = {{ counts }}) %>%
     tidyr::drop_na()
@@ -149,7 +145,6 @@ contingency_table <- function(data,
 
   # Bayesian ---------------------------------------
 
-  # two-way table
   if (type == "bayes" && test == "2way") {
     stats_df <- BayesFactor::contingencyTableBF(
       xtab,
@@ -160,17 +155,14 @@ contingency_table <- function(data,
       tidy_model_parameters(ci = conf.level, effectsize_type = "cramers_v")
   }
 
-  # one-way table
   if (type == "bayes" && test == "1way") {
     # probability can't be exactly 0 or 1
-    if (1 / length(as.vector(xtab)) == 0 || 1 / length(as.vector(xtab)) == 1) {
+    if ((1 / length(as.vector(xtab)) == 0) || (1 / length(as.vector(xtab)) == 1)) {
       return(NULL)
     }
 
-    # use it
     p1s <- rdirichlet(n = 100000L, alpha = prior.concentration * ratio)
 
-    # prob
     pr_h1 <- sapply(
       X = 1:100000,
       FUN = function(i) stats::dmultinom(as.matrix(xtab), prob = p1s[i, ], log = TRUE)
@@ -189,7 +181,6 @@ contingency_table <- function(data,
             {prior_switch(method)}=='{format_value(prior.scale, k)}')")) %>%
       .glue_to_expression()
 
-    # special case: return early since the expression has already been prepared
     return(stats_df)
   }
 
@@ -200,7 +191,7 @@ contingency_table <- function(data,
 
 
 #' @title estimate log prob of data under null with Monte Carlo
-#' @note `rdirichlet` function from `{MCMCpack}`
+#' @note `rdirichlet()` function from `{MCMCpack}`
 #' @noRd
 rdirichlet <- function(n, alpha) {
   l <- length(alpha)
