@@ -4,7 +4,7 @@
 #' @description
 #' Parametric, non-parametric, robust, and Bayesian random-effects meta-analysis.
 #'
-#' @param data A dataframe. It **must** contain columns named `estimate` (effect
+#' @param data A data frame. It **must** contain columns named `estimate` (effect
 #'   sizes or outcomes)  and `std.error` (corresponding standard errors). These
 #'   two columns will be used:
 #'   - as `yi`  and `sei` arguments in `metafor::rma` (for **parametric** test)
@@ -36,40 +36,43 @@
 #' needed package (`{metafor}`, `{metaplus}`, or `{metaBMA}`) for meta-analysis.
 #' If they are not available, you will be asked to install them.
 #'
-#' @examplesIf requireNamespace("metafor", quietly = TRUE)
-#' \donttest{
+#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metafor", quietly = TRUE)
 #' # setup
 #' set.seed(123)
 #' library(statsExpressions)
 #' options(tibble.width = Inf, pillar.bold = TRUE, pillar.neg = TRUE)
 #'
 #' # a data frame with estimates and standard errors (`mag` dataset from `{metaplus}`)
-#' df <- structure(list(
-#'   study = structure(c(
-#'     8L, 10L, 15L, 1L, 4L, 11L, 3L, 2L, 14L, 9L, 12L, 5L, 16L, 7L, 13L, 6L
-#'   ), .Label = c(
-#'     "Abraham", "Bertschat", "Ceremuzynski", "Feldstedt", "Golf",
-#'     "ISIS-4", "LIMIT-2", "Morton", "Pereira", "Rasmussen", "Schechter", "Schechter 1",
-#'     "Schechter 2", "Singh", "Smith", "Thogersen"
-#'   ), class = "factor"),
-#'   estimate = c(
-#'     -0.8303483, -1.056053, -1.27834, -0.0434851, 0.2231435,
-#'     -2.40752, -1.280934, -1.191703, -0.695748, -2.208274, -2.03816,
-#'     -0.8501509, -0.7932307, -0.2993399, -1.570789, 0.0575873
-#'   ),
-#'   std.error = c(
-#'     1.24701799987009, 0.41407060026039, 0.808139200261935,
-#'     1.42950999996502, 0.489168400451215, 1.07220799987689, 1.1937340001022,
-#'     1.66129199992054, 0.536177600240816, 1.10964800004326, 0.780726300312728,
-#'     0.618448600127771, 0.625866199758383, 0.146572899950844,
-#'     0.574039500383031, 0.0316420922190679
-#'   )
-#' ), row.names = c(NA, -16L), class = "data.frame")
+#' df <- tibble::tribble(
+#'   ~study, ~estimate, ~std.error,
+#'   "Abraham", -0.83, 1.247,
+#'   "Bertschat", -1.056, 0.414,
+#'   "Ceremuzynski", -1.278, 0.808,
+#'   "Feldstedt", -0.043, 1.429,
+#'   "Golf", 0.223, 0.489,
+#'   "ISIS-4", -2.407, 1.072,
+#'   "LIMIT-2", -1.28, 1.193,
+#'   "Morton", -1.191, 1.661,
+#'   "Pereira", -0.695, 0.536,
+#'   "Rasmussen", -2.208, 1.109,
+#'   "Schechter", -2.038, 0.78,
+#'   "Schechter 1", -0.85, 0.618,
+#'   "Schechter 2", -0.793, 0.625,
+#'   "Singh", -0.299, 0.146,
+#'   "Smith", -1.57, 0.574,
+#'   "Thogersen", 0.057, 0.031
+#' )
 #'
-#' meta_analysis(df) # parametric
-#' # meta_analysis(df, type = "random", random = "normal") # robust
-#' # meta_analysis(df, type = "bayes") # Bayesian
-#' }
+#' # parametric
+#' meta_analysis(df)
+#'
+#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metaplus", quietly = TRUE)
+#' # robust
+#' meta_analysis(df, type = "random", random = "normal")
+#'
+#' @examplesIf identical(Sys.getenv("NOT_CRAN"), "true") && requireNamespace("metaBMA", quietly = TRUE)
+#' # Bayesian
+#' meta_analysis(df, type = "bayes") # Bayesian
 #' @export
 meta_analysis <- function(data,
                           type = "parametric",
@@ -77,7 +80,6 @@ meta_analysis <- function(data,
                           k = 2L,
                           conf.level = 0.95,
                           ...) {
-  # check the type of test
   type <- stats_type_switch(type)
 
   # additional arguments
@@ -90,22 +92,14 @@ meta_analysis <- function(data,
   if (type == "bayes") c(.ns, .fn)      %<-% c("metaBMA", "meta_random")
   # styler: on
 
-  # needed package installed?
   check_if_installed(.ns)
 
-  # construct a call and then extract a tidy dataframe
+  # construct a call and then extract a tidy data frame
   stats_df <- eval(call2(.fn = .fn, .ns = .ns, data = data, !!!.f.args)) %>%
     tidy_model_parameters(include_studies = FALSE, ci = conf.level)
 
-  # add a column describing effect size
   if (type != "bayes") stats_df %<>% mutate(effectsize = "meta-analytic summary estimate")
   if (type == "bayes") stats_df %<>% mutate(effectsize = "meta-analytic posterior estimate")
 
-  # add expression column
-  add_expression_col(
-    data     = stats_df,
-    n        = nrow(data),
-    n.text   = list(quote(italic("n")["effects"])),
-    k        = k,
-  )
+  add_expression_col(stats_df, n = nrow(data), n.text = list(quote(italic("n")["effects"])), k = k)
 }
