@@ -24,8 +24,7 @@
 #' ```{r child="man/rmd-fragments/return.Rmd"}
 #' ```
 #'
-#' @examples
-#' \donttest{
+#' @examples identical(Sys.getenv("NOT_CRAN"), "true")
 #' # for reproducibility
 #' set.seed(123)
 #' library(statsExpressions)
@@ -110,7 +109,6 @@
 #'   subject.id = subject,
 #'   type       = "bayes"
 #' )
-#' }
 #' @export
 two_sample_test <- function(data,
                             x,
@@ -127,21 +125,17 @@ two_sample_test <- function(data,
                             tr = 0.2,
                             nboot = 100L,
                             ...) {
-  # standardize the type of statistics
   type <- stats_type_switch(type)
 
-  # make sure both quoted and unquoted arguments are supported
   c(x, y) %<-% c(ensym(x), ensym(y))
 
-  # properly removing NAs if it's a paired design
-  data %<>%
-    long_to_wide_converter(
-      x          = {{ x }},
-      y          = {{ y }},
-      subject.id = {{ subject.id }},
-      paired     = paired,
-      spread     = ifelse(type %in% c("bayes", "robust"), paired, FALSE)
-    )
+  data %<>% long_to_wide_converter(
+    x          = {{ x }},
+    y          = {{ y }},
+    subject.id = {{ subject.id }},
+    paired     = paired,
+    spread     = ifelse(type %in% c("bayes", "robust"), paired, FALSE)
+  )
 
   # parametric ---------------------------------------
 
@@ -186,7 +180,6 @@ two_sample_test <- function(data,
   # robust ---------------------------------------
 
   if (type == "robust") {
-    # expression parameters
     k.df <- ifelse(paired, 0L, k)
 
     # styler: off
@@ -204,7 +197,6 @@ two_sample_test <- function(data,
     # styler: on
   }
 
-  # combining data frames
   if (type != "bayes") {
     stats_df <- bind_cols(select(stats_df, -matches("^est|^eff|conf|^ci")), select(effsize_df, -matches("term")))
   }
