@@ -3,9 +3,6 @@ withr::local_options(list(tibble.width = Inf))
 test_that(
   desc = "one_sample_test parametric works",
   code = {
-    # parametric -------------------------------------------------
-
-    # Hedge's g and non-central
     set.seed(123)
     df1 <- one_sample_test(
       data = sample_frac(movies_long, 0.05),
@@ -15,7 +12,6 @@ test_that(
       k = 5
     )
 
-    # Cohen's d and non-central
     set.seed(123)
     df2 <- suppressWarnings(
       one_sample_test(
@@ -24,7 +20,7 @@ test_that(
         test.value = 120,
         type = "p",
         effsize.type = "d",
-        k = 4,
+        k = 4L,
         conf.level = 0.90
       )
     )
@@ -41,9 +37,6 @@ test_that(
 test_that(
   desc = "one_sample_test non-parametric works",
   code = {
-    # non-parametric --------------------------------------------------
-
-    # statsExpressions output
     set.seed(123)
     df1 <- suppressWarnings(one_sample_test(
       data = ToothGrowth,
@@ -53,7 +46,7 @@ test_that(
       k = 4
     ))
 
-    # statsExpressions output
+
     set.seed(123)
     df2 <- one_sample_test(
       data = msleep,
@@ -75,31 +68,27 @@ test_that(
 test_that(
   desc = "one_sample_test robust works",
   code = {
-    # robust --------------------------------------------------
-
-    # statsExpressions output
     set.seed(123)
     df1 <- one_sample_test(
       data = anscombe,
       x = x1,
       test.value = 8,
       type = "r",
-      k = 4,
+      k = 4L,
       conf.level = 0.90
     )
 
-    # statsExpressions output
+
     set.seed(123)
     df2 <- one_sample_test(
       data = msleep,
       x = brainwt,
       test.value = 0.1,
       type = "r",
-      k = 4,
+      k = 4L,
       conf.level = 0.99
     )
 
-
     set.seed(123)
     expect_snapshot(select(df1, -expression))
     expect_snapshot(df1[["expression"]])
@@ -112,9 +101,6 @@ test_that(
 test_that(
   desc = "one_sample_test bayesian works",
   code = {
-    # Bayesian -----------------------------------------------
-
-    # extracting results from where this function is implemented
     set.seed(123)
     df_results <-
       one_sample_test(
@@ -123,12 +109,10 @@ test_that(
         x = Petal.Length,
         y = NULL,
         test.value = 5.5,
-        bf.prior = 0.99,
+        bf.prior = 0.99
       )
 
-    # check Bayes factor values
     expect_equal(df_results$bf10[[1]], 5.958171e+20, tolerance = 0.001)
-
     expect_snapshot(names(df_results))
 
     # extracting subtitle (without NA)
@@ -154,7 +138,7 @@ test_that(
       y = NULL,
       test.value = 0.25,
       bf.prior = 0.9,
-      k = 3,
+      k = 3L,
       conf.method = "eti"
     )
 
