@@ -1,17 +1,15 @@
 withr::local_options(list(tibble.width = Inf))
+skip_if_not_installed("afex")
 
 test_that(
   desc = " parametric t-tests",
   code = {
-    skip_if(getRversion() < "4.0")
-
-
     # one-sample t-test (with NAs) ---------
 
     set.seed(123)
     df_1 <- purrr::pmap_dfr(
       .l = list(
-        data = list(ggplot2::msleep),
+        data = list(msleep),
         x = list("brainwt"),
         test.value = list(0.25),
         effsize.type = list("d", "g", "d", "g"),
@@ -68,7 +66,7 @@ test_that(
     set.seed(123)
     df_3_between <- purrr::pmap_dfr(
       .l = list(
-        data = list(ggplot2::msleep),
+        data = list(msleep),
         x = list("vore"),
         y = list("sleep_rem"),
         effsize.type = list("eta", "omega", "eta", "omega"),
