@@ -5,7 +5,6 @@ test_that(
   code = {
     # between-subjects -------------------------------------------------------
 
-
     set.seed(123)
     df1 <- oneway_anova(
       type = "robust",
@@ -13,12 +12,11 @@ test_that(
       x = cyl,
       y = wt,
       paired = FALSE,
-      k = 5,
+      k = 5L,
       tr = 0.00025,
       nboot = 2
     )
 
-
     set.seed(123)
     df2 <- suppressWarnings(oneway_anova(
       type = "robust",
@@ -26,17 +24,15 @@ test_that(
       x = vore,
       y = sleep_total,
       paired = FALSE,
-      k = 4,
+      k = 4L,
       nboot = 15,
       conf.level = 0.99
     ))
 
-
     set.seed(123)
     expect_snapshot(select(df1, -expression))
     expect_snapshot(df1[["expression"]])
 
-
     set.seed(123)
     expect_snapshot(select(df2, -expression))
     expect_snapshot(df2[["expression"]])
@@ -48,7 +44,6 @@ test_that(
   code = {
     # within-subjects -------------------------------------------------------
 
-
     set.seed(123)
     df1 <- oneway_anova(
       type = "robust",
@@ -59,7 +54,6 @@ test_that(
       paired = TRUE
     )
 
-
     set.seed(123)
     expect_snapshot(select(df1, -expression))
     expect_snapshot(df1[["expression"]])
